from enum import Enum


class GenerationsStyle(Enum):
    """
    Enums for generation style_ids
    """

    STYLE_ANIME = 21
    STYLE_PORTRAIT = 26
    STYLE_IMAGINE_V1 = 27
    STYLE_IMAGINE_V3 = 28
    STYLE_REALISTIC = 29
    STYLE_IMAGINE_V4 = 30
    STYLE_IMAGINE_V4_CREATIVE = 31
    STYLE_IMAGINE_V4_1 = 32
    STYLE_IMAGINE_V5 = 33
    STYLE_DELIBERATE = 100
    STYLE_MAGIC_MIX = 101
    STYLE_DISNEY = 102
    STYLE_ABYSS_ORANGE_MIX = 103
    STYLE_LYRIEL = 104
    STYLE_RPG_4 = 105
    STYLE_REALISTIC_VISION = 110
    STYLE_DREAM_SHAPER = 111
    STYLE_REV_ANIMATED = 112
    STYLE_TOON_YOU = 113
    STYLE_UNREAL_ENGINE_5 = 114
    STYLE_EPIC_REALISM = 115
    STYLE_MEINA_MIX = 116
    STYLE_XX_MIX_9_REALISTIC = 117
    STYLE_3D_RENDERING_STYLE = 118
    STYLE_ABSOLUTE_REALITY_V1_6 = 119
